% Nonlinear model of two CSTRs in series from
%
% Hahn, J. and T.F. Edgar, An improved method for nonlinear model reduction using balancing of
%   empirical gramians, Computers and Chemical Engineering, 26, pp. 1379-1397, (2002)
%
%  t -- time (not used)
%  y -- state value vector
%  xdot -- set to the vector of state derivatives

function xdot = cstr4(t,x)

global u

% Inputs (2):
% Valve position at the outlet of the second reactor
u1 = u(1,1);
% Heat transferred to the first reactor (J/min)
u2 = u(2,1);

% States (6):
% Volume of Reactor #1 (L)
V1 = x(1,1);
% Concentration of A in Reactor #1 (mol/L)
Ca1 = x(2,1);
% Temperature of Reactor #1 (K)
T1 = x(3,1);
% Volume of Reactor #2 (L)
V2 = x(4,1);
% Concentration of A in Reactor #2 (mol/L)
Ca2 = x(5,1);
% Temperature of Reactor #2 (K)
T2 = x(6,1);

% Parameters
% Constant 1
c1 = 10;
% Constant 2
c2 = 48.1909;
% Feed Volumetric Flowrate (L/min)
qf = 100.0 ;
% Feed Concentration of A (mol/L)
Caf = 1.0;
% Feed Temperature (K)
Tf	= 350.0 ;
% Flowrate out of Reactor #1 (L/min) 
q1 = c1*sqrt(V1-V2);
% Flowrate out of Reactor #2 (L/min)
q2 = c1*sqrt(V2)*u1;
% Energy Flow from Reactor #1 - Cooling (J/min)
Qc	= - c2 * u2;
% Pre-exponential Factor for A->B Arrhenius Equation
k0 = 7.2e10;
% EoverR - E/R (K) - Activation Energy (J/mol) / Gas Constant (J/mol-K)
EoverR = 1e4;
% Density of Fluid (g/L)
rho = 1000;
% Heat Capacity of Fluid (J/g-K)
Cp = 0.239;
% Heat of Reaction (J/mol)
dH = 4.78e4;

%	Dynamic Balances
 
%	dV1/dt 
xdot(1,1) = qf - q1;
%	dCa1/dt
xdot(2,1) = qf*Caf/V1 - k0*Ca1*exp(-EoverR/T1) - q1*Ca1/V1 - Ca1/V1*xdot(1,1);
%	dT1/dt
xdot(3,1) = qf*Tf/V1 + (dH*k0/rho/Cp)*Ca1*exp(-EoverR/T1) - q1*T1/V1 + Qc - T1/V1*xdot(1,1);
%	dV2/dt
xdot(4,1) = q1 - q2;
%	dCa2/dt
xdot(5,1) = q1*Ca1/V2 - k0*Ca2*exp(-EoverR/T2) - q2*Ca2/V2 - Ca2/V2*xdot(4,1);
%	dT2/dt
xdot(6,1)  = q1*T1/V2 + (dH*k0/rho/Cp)*Ca2*exp(-EoverR/T2) - q2*T2/V2 - T2/V2*xdot(4,1);